@@ -15,6 +15,7 @@ class GoogleCloudPilotAPI(abc.ABC):
     _client_class = None
     _scopes = ['https://www.googleapis.com/auth/cloud-platform']
     _iam_roles = []
+    _cached_credentials = None
 
     def __init__(self, subject=None, location=None, **kwargs):
         self.credentials, project_id = self._build_credentials(subject=subject)
@@ -31,7 +32,12 @@ class GoogleCloudPilotAPI(abc.ABC):
 
     @classmethod
     def _build_credentials(cls, subject=None):
-        credentials, project_id = auth.default()
+        # Speed up consecutive authentications
+        if not cls._cached_credentials:
+            credentials, project_id = auth.default()
+            cls._cached_credentials = credentials, project_id
+
+        credentials, project_id = cls._cached_credentials
         if subject:
             credentials = credentials.with_subject(subject=subject)
         return credentials, project_id
